@@ -3,7 +3,7 @@
  * \brief interface for all frame classes
  * \see mlt_frame_s
  *
- * Copyright (C) 2003-2023 Meltytech, LLC
+ * Copyright (C) 2003-2025 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -442,6 +442,7 @@ static int generate_test_image(mlt_properties properties,
         case mlt_image_yuv422p16:
         case mlt_image_yuv420p10:
         case mlt_image_yuv444p10:
+        case mlt_image_rgba64:
             break;
         case mlt_image_none:
         case mlt_image_movit:
@@ -459,9 +460,7 @@ static int generate_test_image(mlt_properties properties,
 
         if (mlt_properties_get_int(properties, "test_audio")) {
             const char *color_range = mlt_properties_get(properties, "consumer.color_range");
-            int full_range = color_range
-                             && (!strcmp("pc", color_range) || !strcmp("jpeg", color_range));
-            mlt_image_fill_white(&img, full_range);
+            mlt_image_fill_white(&img, mlt_image_full_range(color_range));
         } else {
             mlt_image_fill_checkerboard(&img, mlt_properties_get_double(properties, "aspect_ratio"));
         }
@@ -541,7 +540,7 @@ int mlt_frame_get_image(mlt_frame self,
 
 /** Get the alpha channel associated to the frame (without creating if it has not).
  *
- * This returns NULL if the frame's image format is \p mlt_image_rgba.
+ * This returns NULL if the frame's image format is \p mlt_image_rgba or mlt_image_rgba64.
  * \public \memberof mlt_frame_s
  * \param self a frame
  * \return the alpha channel or NULL
@@ -554,7 +553,7 @@ uint8_t *mlt_frame_get_alpha(mlt_frame self)
         alpha = mlt_properties_get_data(&self->parent, "alpha", NULL);
         if (alpha) {
             mlt_image_format format = mlt_properties_get_int(&self->parent, "format");
-            if (mlt_image_rgba == format) {
+            if (mlt_image_rgba == format || format == mlt_image_rgba64) {
                 alpha = NULL;
             }
         }
@@ -565,7 +564,7 @@ uint8_t *mlt_frame_get_alpha(mlt_frame self)
 /** Get the alpha channel associated to the frame and its size.
  *
  * This returns NULL and sets \p size to 0 if the frame's image format is
- * \p mlt_image_rgba.
+ * \p mlt_image_rgba or mlt_image_rgba64.
  *
  * \public \memberof mlt_frame_s
  * \param self a frame
@@ -579,7 +578,7 @@ uint8_t *mlt_frame_get_alpha_size(mlt_frame self, int *size)
         alpha = mlt_properties_get_data(&self->parent, "alpha", size);
         if (alpha) {
             mlt_image_format format = mlt_properties_get_int(&self->parent, "format");
-            if (mlt_image_rgba == format) {
+            if (mlt_image_rgba == format || mlt_image_rgba64 == format) {
                 alpha = NULL;
                 if (size) {
                     size = 0;
@@ -644,6 +643,7 @@ int mlt_frame_get_audio(mlt_frame self,
         *samples = *samples <= 0 ? 1920 : *samples;
         *channels = *channels <= 0 ? 2 : *channels;
         *frequency = *frequency <= 0 ? 48000 : *frequency;
+        *format = *format == mlt_audio_none ? mlt_audio_s16 : *format;
         mlt_properties_set_int(properties, "audio_frequency", *frequency);
         mlt_properties_set_int(properties, "audio_channels", *channels);
         mlt_properties_set_int(properties, "audio_samples", *samples);
